import { logger } from '@/module/logger.ts';
import { program, Command, assistantConfig } from '@/program.ts';
import { AppDownload } from '@/services/app/index.ts';

const commdands = ['app', 'page'];
const addOneCommand = (name: string) => {

  const appManagerCommand = new Command(name).description(`本地的应用模块的安装和下载, 分为 app 和 web 两种类型. 默认类型为${name}`);
  program.addCommand(appManagerCommand);

  const downloadCommand = new Command('download')
    .description('下载应用')
    .option('-i, --id <id>', '应用名称')
    .option('-t, --type <type>', '应用类型', name)
    .option('-r, --registry <registry>', '应用源 https://kevisual.cn')
    .option('-f --force', '强制覆盖')
    .option('-y --yes', '覆盖的时候不提示')
    .action(async (options) => {
      const { id, type, force, yes } = options;
      assistantConfig.checkMounted();
      const registry = options.registry || assistantConfig.getRegistry();
      // console.log('registry', registry);
      const app = new AppDownload(assistantConfig);
      let info = '';
      if (id) {
        const msg = await app.downloadApp({ id, type, registry, force, yes });
        info = String(msg);
      }
      logger.debug(info);
    });

  appManagerCommand.addCommand(downloadCommand);

  const deleteCommand = new Command('delete')
    .description('删除应用')
    .option('-i, --id <id>', '应用名称')
    .option('-t, --type <type>', '应用类型', name)
    .action(async (options) => {
      const { id, type } = options;
      const app = new AppDownload(assistantConfig);
      let info = '';
      if (id) {
        const msg = await app.deleteApp({ id, type });
        info = String(msg);
      }
      logger.debug(info);
    });
  appManagerCommand.addCommand(deleteCommand);

  const uploadCommand = new Command('upload')
    .description('上传应用')
    .option('-i, --id <id>', '应用名称 root/app-name 的格式，如果是后端，会自动解析为 app-name')
    .option('-t, --type <type>', '应用类型', 'app')
    .action(async (options) => {
      //
    });
};

commdands.forEach((name) => {
  addOneCommand(name);
});